<?php
/**
 * This file is part of workerman.
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the MIT-LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @author walkor<walkor@workerman.net>
 * @copyright walkor<walkor@workerman.net>
 * @link http://www.workerman.net/
 * @license http://www.opensource.org/licenses/mit-license.php MIT License
 */

/**
 * 聊天主逻辑
 * 主要是处理 onMessage onClose 
 */
use \GatewayWorker\Lib\Gateway;
use \GatewayWorker\Lib\Store;

class Event
{
   
   /**
    * 有消息时
    * @param int $client_id
    * @param string $message
    */
   public static function onMessage($client_id, $message)
   {
        // debug
        echo "client:{$_SERVER['REMOTE_ADDR']}:{$_SERVER['REMOTE_PORT']} gateway:{$_SERVER['GATEWAY_ADDR']}:{$_SERVER['GATEWAY_PORT']}  client_id:$client_id session:".json_encode($_SESSION)." onMessage:".$message."\n";
        
        // 客户端传递的是json数据
        $message_data = json_decode($message, true);
        if(!$message_data)
        {
            return ;
        }
        
        // 根据类型执行不同的业务
        switch($message_data['type'])
        {
            // 客户端回应服务端的心跳
            case 'pong':
                return;
            // 客户端登录 message格式: {type:login, name:xx, com_id:1} ，添加到客户端，广播给所有客户端xx进入聊天室
            case 'login':
                // 判断是否有房间号
                if(!isset($message_data['com_id']))
                {
                    throw new \Exception("\$message_data['com_id'] not set. client_ip:{$_SERVER['REMOTE_ADDR']} \$message:$message");
                }
                
                // 把房间号昵称放到session中
                $com_id = $message_data['com_id'];
                $client_uid = htmlspecialchars($message_data['client_uid']);
                $_SESSION['com_id'] = $com_id;
                $_SESSION['client_uid'] = $client_uid;
                

                // 获取房间内所有用户列表 
                $clients_list = Gateway::getClientInfoByGroup($com_id);
                foreach($clients_list as $tmp_client_id=>$item)
                {
                    $clients_list[$tmp_client_id] = $item['client_uid'];
                }
                
                $clients_list[$client_id] = $client_uid;
                
                // 转播给当前房间的所有客户端，xx进入聊天室 message {type:login, client_id:xx, name:xx} 
                $new_message = array('type'=>$message_data['type'], 'client_id'=>$client_id, 'client_uid'=>htmlspecialchars($client_uid), 'time'=>date('Y-m-d H:i:s'));
                Gateway::sendToGroup($com_id, json_encode($new_message));
                Gateway::joinGroup($client_id, $com_id);
               
                // 给当前用户发送用户列表 
                $new_message['client_list'] = $clients_list;
                Gateway::sendToCurrentClient(json_encode($new_message));
                
                return;
                
            // 客户端发言 message: {type:say, to_client_id:xx, content:xx}
            case 'say':
                // 非法请求
                if(!isset($_SESSION['com_id']))
                {
                    throw new \Exception("\$_SESSION['com_id'] not set. client_ip:{$_SERVER['REMOTE_ADDR']}");
                }
                $com_id = $_SESSION['com_id'];
                $client_uid = $_SESSION['client_uid'];
                
                // 私聊
                if($message_data['to_client_id'] != 'all')
                {
                    $new_message = array(
                        'type'=>'say',
                        'from_client_id'=>$client_id, 
                        'from_client_uid' =>$client_uid,
                        'to_client_id'=>$message_data['to_client_id'],
                        'content'=>"<b>对你说: </b>".nl2br(htmlspecialchars($message_data['content'])),
                        'time'=>date('Y-m-d H:i:s'),
                    );
                    Gateway::sendToClient($message_data['to_client_id'], json_encode($new_message));
                    $new_message['content'] = "<b>你对".htmlspecialchars($message_data['to_client_uid'])."说: </b>".nl2br(htmlspecialchars($message_data['content']));
                    return Gateway::sendToCurrentClient(json_encode($new_message));
                }
                
                $new_message = array(
                    'type'=>'say', 
                    'from_client_id'=>$client_id,
                    'from_client_uid' =>$client_uid,
                    'to_client_id'=>'all',
                    'content'=>nl2br(htmlspecialchars($message_data['content'])),
                    'time'=>date('Y-m-d H:i:s'),
                );
                return Gateway::sendToGroup($com_id ,json_encode($new_message));

            case 'system':
                $com_id = $message_data['com_id'];
                $level  = $message_data['level'];
                $content = $message_data['content'];

                $new_message = array(
                    'type'=>'system', 
                    'level'=>nl2br(htmlspecialchars($message_data['level'])),
                    'content'=>nl2br(htmlspecialchars($message_data['content'])),
                    'time'=>date('Y-m-d H:i:s'),
                );
                return Gateway::sendToGroup($com_id ,json_encode($new_message));

            case 'action':
                $com_id = $message_data['com_id'];
                $new_message = array(
                    'type'=>'action', 
                    'action'=>nl2br(htmlspecialchars($message_data['action'])),
                    'time'=>date('Y-m-d H:i:s'),
                );
                return Gateway::sendToGroup($com_id ,json_encode($new_message));

            case 'digital':
                $com_id = $message_data['com_id'];
                $new_message = array(
                    'type'=>'digital', 
                    'action'=>nl2br(htmlspecialchars($message_data['action'])),
                    'level'=>nl2br(htmlspecialchars($message_data['level'])),
                    'img'=>nl2br(htmlspecialchars($message_data['img'])),
                    'type_mode'=>nl2br(htmlspecialchars($message_data['type_mode'])),
                    'time'=>date('Y-m-d H:i:s'),
                );
                return Gateway::sendToGroup($com_id ,json_encode($new_message));
        }
   }
   
   /**
    * 当客户端断开连接时
    * @param integer $client_id 客户端id
    */
   public static function onClose($client_id)
   {
       // debug
       echo "client:{$_SERVER['REMOTE_ADDR']}:{$_SERVER['REMOTE_PORT']} gateway:{$_SERVER['GATEWAY_ADDR']}:{$_SERVER['GATEWAY_PORT']}  client_id:$client_id onClose:''\n";
       
       // 从房间的客户端列表中删除
       if(isset($_SESSION['com_id']))
       {
           $com_id = $_SESSION['com_id'];
           $new_message = array('type'=>'logout', 'from_client_id'=>$client_id, 'from_client_uid'=>$_SESSION['client_uid'], 'time'=>date('Y-m-d H:i:s'));
           Gateway::sendToGroup($com_id, json_encode($new_message));
       }
   }

   public function onTest($data)
   {
        echo $data."\n";
   }
  
}
